@@ -1,13 +1,32 @@
+import dataclasses
 from typing import Any, Optional, Union
 
 import pytest
 
-from libvcs._internal.query_list import QueryList
+from libvcs._internal.query_list import (
+    MultipleObjectsReturned,
+    ObjectDoesNotExist,
+    QueryList,
+)
+
+
+@dataclasses.dataclass
+class Obj:
+    test: int
+    fruit: list[str] = dataclasses.field(default_factory=list)
 
 
 @pytest.mark.parametrize(
     "items,filter_expr,expected_result",
     [
+        [[Obj(test=1)], None, [Obj(test=1)]],
+        [[Obj(test=1)], dict(test=1), [Obj(test=1)]],
+        [[Obj(test=1)], dict(test=2), []],
+        [
+            [Obj(test=2, fruit=["apple"])],
+            dict(fruit__in="apple"),
+            QueryList([Obj(test=2, fruit=["apple"])]),
+        ],
         [[{"test": 1}], None, [{"test": 1}]],
         [[{"test": 1}], None, QueryList([{"test": 1}])],
         [[{"fruit": "apple"}], None, QueryList([{"fruit": "apple"}])],
@@ -242,3 +261,28 @@ def test_filter(
             assert qs.filter(filter_expr) == expected_result
     else:
         assert qs.filter() == expected_result
+
+    if (
+        isinstance(expected_result, list)
+        and len(expected_result) > 0
+        and not isinstance(expected_result[0], dict)
+    ):
+        if len(expected_result) == 1:
+            if isinstance(filter_expr, dict):
+                assert qs.get(**filter_expr) == expected_result[0]
+            else:
+                assert qs.get(filter_expr) == expected_result[0]
+        elif len(expected_result) > 1:
+            with pytest.raises(MultipleObjectsReturned) as e:
+                if isinstance(filter_expr, dict):
+                    assert qs.get(**filter_expr) == expected_result
+                else:
+                    assert qs.get(filter_expr) == expected_result
+                assert e.match("Multiple objects returned")
+        elif len(expected_result) == 0:
+            with pytest.raises(ObjectDoesNotExist) as exc:
+                if isinstance(filter_expr, dict):
+                    assert qs.get(**filter_expr) == expected_result
+                else:
+                    assert qs.get(filter_expr) == expected_result
+            assert exc.match("No objects found")
